# Code of Conduct

This project follows the [Contributor Covenant v2.1](https://www.contributor-covenant.org/version/2/1/code_of_conduct/).

By participating in this project, you agree to abide by its terms.

## Reporting

If you experience or witness unacceptable behavior, please contact us at [conduct@elnora.ai](mailto:conduct@elnora.ai).

All reports will be reviewed and investigated promptly and fairly. All community leaders are obligated to respect the privacy and security of the reporter.
